%%% Processing first breaks from University Drive line
%%% LOAD picks, set up geometry
%%% ============================================================

addpath matlab/		% use processing codes from directory matlab/

%% Set global variables to pass data to various functions

global ttdata 	 	% list of all travel-time picks 
global src rec recline	% tables of source and receiver parameters
global model		% structure that will contain our model
global ttpred		% modeled travel times
global procdata		% optional parameters passed to various programs

%% After running this code and looking at the results, 
%% notice some errors in the data and set up corrections for them:

procdata.correct_tt = [ 71, 13.0 ];	% this will add 13 ms to all times picked from FFID 71
					% if there are no corrections, this variable should equal []

procdata.correct_src_x = [ 	55, 0.2
				56, 0.2
				69, 1.0 	% this will shift source location for FFID 69 by 1 meter
			];			% if there are no corrections, this variable should equal []
  
procdata.correct_ttimes = 'none';	% this key word is used in ttimes_src() to apply
					% various corrections to travel times 

%% load the file from GeoTomo into ttdata, src, and rec

%load_picks("L3_01.txt")
load_picks("FirstArrivalTravelTimes.txt")

%% after all picks are loaded, initialize the model

init_model()

%% plot the line and cross-section 

plot_model()

%% measure and plot reciprocal travel-time mismatches

rtt0 = ttimes_reciprocal();

plot_rtt(rtt0)

%% invert reciprocal time mismatches for shot time corrections

st = shot_times(rtt0,'apply');	% this applies shot time correction to data 

%% measure reciprocal error again and plot final results

rtt = ttimes_reciprocal();	

plot_rtt(rtt0, rtt)	

%% save all results in .mat file

save lab4.mat src rec recline model *data 

