%%% Pass 2 of processing first breaks from University Drive line
%%% IDENTIFYING travel time braches and cross-over distances
%%% ============================================================
%%
%% Run this code once and then repeat calls plot_ttimes_* in it with different
%% combinations of parameters.

%% The purpose of this script is to make changes in matrices 
%% 'model.crossover' and 'model.mute' below. These matrices contain information
%% about particioning of the travel-time picks into direct-wave and head-wave branches

%% After you have iterated the plot_times_* above and edited tables,  
%% run again: 
%%	lab4_pass1 
%%	lab4_pass2
%% and do not make any changes in the tables.
%% -------------------------------------------------------------------
%% DO NOT EXECUTE lab4_pass2 more then once! If you need to do this, run lab4_pass1 first
%% =====================================================================================


addpath matlab/		% use processing codes from directory matlab/

%% Set global variables to pass data to various functions

global ttdata 		% list of all travel-time picks 
global src rec recline	% tables of source and receiver parameters
global model		% structure that will contain our model
global procdata		% optional parameters passed to various programs

%% load results of pass 1

load lab4.mat	

%% define crossover distances as functions of midpoint coordinate on the line
%% (columns are: midpoint_distance, crossover_1, crossover_2, ...
%% values smaller than preceding ones mean no such branch)
%%
%% Here are the values from my rough test:

model.crossover = [ 	-100, 	10,	22
			25, 	10,	25 	
			40, 	8,	18 
			60, 	16	20
			100, 	10 	20
		];

%% define offset mute distances as functions of midpoint coordinate on the line
%% (there are only two columns: midpoint_distance, mute_offset)
  
model.mute = [ 	-100, 1.5
		100, 1.5 ];

%% request corrections of picked times for zero-offset dalays 
%% (these dalays are initially zero but inverted for in measure_p_int()
%%

procdata.correct_ttimes = 'delta0';	% subtract zero-offset delays from travel times 

%% Measure slopes and intercepts for each layer
%% and invert for near-surface velocities and "direct-wave" delays

measure_p_int();

% After measure_p_int('apply'), the travel times for shots and midpoints
% should be aligned better

%% plot all picked travel times

plot_ttimes()

%% plot travel times at groups of sources with travel-time reduction 0.4 m/ms

plot_ttimes_src( [ 1, 10; 10, 20; 21, 33], 0.35 )

%% plot travel times at control points
%% Try this call several times (can repeat it separately from the rest of the script)
%%
%% In the resulting plots, identify the crossover points and put them in
%% matrix 'model.crossover' above
%%
%% Also check whether matrix 'model.mute' (distances covered by picks drawn in green)
%% need to be updated
%%
%% Examples:  

plot_ttimes_cp( [ 10, 20; 20, 40; 40, 60], 0.35 )

%plot_ttimes_cp( [ 10, 20; 20, 30; 30, 40], 0.35 )

%plot_ttimes_cp( [ 0, 20; 60, 80; 80, 100], 0.35 )

%% plot the final TTF 

plot_ttf()

%% plot the model again 

plot_model()

%% save all results in the same .mat file

save lab4.mat src rec recline model *data ttpred

