%% Returns branch numbers for a common-offset tt curve
%% This is a helper function
%% ------------------------------------------------------------------------------------
%% Parameters:
%%      xmp - column of midpoint coordinates
%%	offset - offset value (should be one number only)
%%  Returns:
%%	b - column of branch numbers for each element of xmp
%% ========================================================================================

function b = branch( xmp, offset )
	
global	model
	
	n = length(xmp);
	
	defbranch = size(model.crossover,2);	% default branch number (largest possible)

	% set branch numbers below defbranch

	b = ones(n,1)*defbranch;

	[ cdist, mute ] = crossover( 1:defbranch, xmp );	% crossovers for each xmp

	for i=size(cdist,2):-1:1
		ind = find(offset < cdist(:,i));

		if ~isempty(ind)
			b(ind,1) = i-1;
		end
	end

	% check mute interval

	ind = find(offset < mute);

	if ~isempty(ind)
		b(ind,1) = -1;		% mute
	end
end

