%% Returns crossover distance for a forward or reverse branch
%% For branch = 0, returns zero crossover distance; if branch != 0 and not defined 
%% in model.crossover, returns Inf
%% For multiple values in array 'branch' returns a column of corssover values for each branch
%%
%% Parameters:
%%      branch - Branch number (1,2,...) (can be an array)
%%		
%%	x -  coordinate on the line (can be a column)
%%  Returns:
%%	cdist - crossover distance (same size as x)
%%	mute_dist - offset mute distance (same size as x)

function [ cdist, mute_dist ] = crossover( branch, x )

global model recline

	if isempty(branch)
		cdist = [];
	else
	  cdist = zeros(length(x),length(branch));

	  for i=1:length(branch)
		if branch(i) < 0
			cdist(:,i) = crossover( -branch(i), x );  % the same as in opposite direction
		elseif branch(i) > 0
			n = branch(i)+1;

			if n <= size(model.crossover,2)
				cdist(:,i) = interp1(model.crossover(:,1),model.crossover(:,n),x,'linear','extrap');
			else
				cdist(:,i) = Inf;
			end
		end
	  end	% for
	end

	% offset mute distance at 'x'

	if isempty(model.mute)
		mute_dist = zeros(size(x,1),1);
	else
		mute_dist = interp1(model.mute(:,1),model.mute(:,2),x,'linear','extrap');
	end
end

