%% Spatial filtering using median operator
%% ---------------------------------------------------------------------
%% Parameters:
%%      u - matrix in which each column is filtered
%%      oplen - operator length (should usually be odd number)
%%
%%  Returns:
%%	uf - filtered u
%% ========================================================================================

function uf = filter_spatial( u, oplen )
 
global  rec

	uf = u;		% init

	n = size(u,1);

	margin = fix(oplen/2);

	% replace edges with median of the adjacent quarter of the survey

	mid = fix(length(u)/4);

	u(1:margin) = median(u((margin+1):mid));
	u((end-margin):end) = median(u((end-mid):(end-margin)));

	% filter each column in u

	for i=1:size(u,2)
		uf1 = [ ones(margin,oplen)*u(1,i); zeros(n,oplen); ones(margin,oplen)*u(end,i) ];

		% insert shifted copies of ith record in the middle

		for k = 1:oplen
			uf1(k:(k+n-1),k) = u(:,i);
		end

		uf2 = median(uf1,2);

		uf(:,i) = uf2(margin+(1:n),:);
	end
end

