%% Measure distance of points along and across the line
%%
%% ---------------------------------------------------------------------
%% Parameters:
%%      st_xyz - Matrix of xyz coordinates of points for which the inline and crossline
%%		coordinates are calculated 
%%
%%  Returns:
%%	in_line - column of in-line coordinates for 'st_xyz'
%%      cross_line - cross-line offsets of points st_xyz 
%%		from the nearest point on line 'xy'
%%      above_datum - hights of points st_xyz above datum
%%	pxyz - matrix of X,Y,Z coordinates of the points on the datum line nearest to 'st_xyz' 
%% ========================================================================================

function [ in_line, cross_line, above_datum, pxyz ] = line_distance( st_xyz )
 
global recline

  ns = size(st_xyz,1);

  in_line = zeros(ns,1);	% initialize
  cross_line = in_line;
  above_datum = in_line;

  pxyz = zeros(ns,3);

  % components of gradient vector in the direction of the line 

  dpx = polyder(recline.px);
  dpy = polyder(recline.py);

  gxy = [ polyval(dpx,recline.xyz(:,1)), polyval(dpy,recline.xyz(:,2)) ];

  a = recline.xyz(end,1:2) - recline.xyz(1,1:2);	% overall direction of the profile

  % measure projections of the vector connecting st_xyz to the line and 
  % gradient along the line, and find points where this projection = 0

  for i=1:ns
	r = recline.xyz(:,1:2) - st_xyz(i,1:2);

	p = dot(r,gxy,2);

  	xnear = interp1(p,recline.x,0.0,'linear','extrap');

  	in_line(i,1) = xnear;

	p0 = interp1(recline.x,recline.xyz(:,1:3),xnear,'linear','extrap');

  	pxyz(i,:) = p0;

	p0(1:2) = p0(1:2) - st_xyz(i,1:2);	% vector from st_xyz to the nearest on profile

	cross_line(i,1) = distance(st_xyz(i,1:2),pxyz(i,1:2))*sign(p0(1)*a(2) - p0(2)*a(1));
  end

  above_datum = st_xyz(:,3) - pxyz(:,3);

end

