%% Measure distance of points along and across the line
%% Distance is set equal 0 at the point given by parameter 'ch'=chan0
%%
%% ---------------------------------------------------------------------
%% Parameters:
%%      st_xyz - Matrix of xyz coordinates of points for which the inline and crossline
%%		coordinates are calculated 
%%      x - in-line coordinate values assigned to these points   
%%
%%  Returns:
%%	in_line - column of in-line coordinates (equal 'x' on return)
%%      cross_line - cross-line offsets of points 'st_xyz' 
%%		from the nearest point on line 'xy'
%%      above_datum - hights of points st_xyz above datum
%%	pxyz - matrix of X,Y,Z coordinates of the points on the datum line nearest to 'st_xyz' 
%% ========================================================================================

function [ in_line, cross_line, above_datum, pxyz ] = line_distance_chan( st_xyz, x )
 
global recline

  in_line = x;

  ns = size(st_xyz,1);

  cross_line = zeros(ns,1);
  above_datum = cross_line;

  a = recline.xyz(end,1:2) - recline.xyz(1,1:2);	% overall direction of the profile

  % measure projections of the vector connecting st_xyz to the line and 
  % gradient along the line, and find points where this projection = 0

  for i=1:ns

	p0 = interp1(recline.x,recline.xyz(:,1:3),x(i),'linear','extrap');

  	pxyz(i,:) = p0;

	p0(1:2) = p0(1:2) - st_xyz(i,1:2);	% vector from st_xyz to the nearest on profile

	cross_line(i,1) = distance(st_xyz(i,1:2),pxyz(i,1:2))*sign(p0(1)*a(2) - p0(2)*a(1));
  end

  above_datum = st_xyz(:,3) - pxyz(:,3);

%figure(777)
%clf
%hold on
%plot(recline.x(:,1),recline.xyz(:,1),'b+')
%plot(recline.x(:,1),recline.xyz(:,2),'r+')
%plot(x,pxyz(:,1),'g+')

end

