%% Measure distance of points along and across the line
%% Distance is set equal 0 at the point given by parameter 'ch'=chan0
%%
%% ---------------------------------------------------------------------
%% Parameters:
%%      srcdat - columns from data file containing source number and x,y coordinates
%%      recdat - columns from data file containing receiver number, x,y, 
%%
%%  Returns:
%%	in_line - column of in-line coordinates (equal 'x' on return)
%%      cross_line - cross-line offsets of points 'st_xyz' 
%%		from the nearest point on line 'xy'
%%      above_datum - hights of points st_xyz above datum
%%	pxyz - matrix of X,Y,Z coordinates of the points on the datum line nearest to 'st_xyz' 
%% ========================================================================================

function [ in_line, cross_line, above_datum, pxyz ] = line_src( srcdat, recdat )
 
global recline src rec

  % for each shot, estimate position using the distances from data file

  x = zeros(size(src,1),1);

  for i=1:size(src,1)

	ind = find(srcdat(:,1)==src(i,1)); 	% row numbers in srcdat and recdat for this source

	if isempty(ind)
		continue
	end

	[ ~, indrec ] = ismember(recdat(ind,1),rec(:,1)); % row numbers in rec for each data point

	if isempty(indrec)
		continue
	end

  	% evaluate distances along line 

	offset = distance(recdat(ind,2:3),srcdat(ind(1,1),2:3)) .*sign(rec(indrec,5)-src(i,5));

	% obtain source position by averaging estimates from all receivers

	x(i,1) = mean( rec(indrec,5) - offset );
  end

  % evaluate in-line and crossline positions for sources using the same algorithm as for receivers

  [ in_line, cross_line, above_datum, pxyz ] = line_distance_chan( src(:,2:4), x );

end

