%% Returns coordinates of all or selected midpoints.
%% Midpoints are placed at and halfway between the coordinates in 'rec'
%% If argument is given, returns coordinate of midpoint closest to it,
%% otherwise returns all midpoints
%% ---------------------------------------------------------------------
%% Parameters:
%%      x - If this parameter is given, midpoints closest to 'x' are returned
%%
%%  Returns:
%%	xmp - column of in-line coordinates of the midpoints
%%	cmpnum - column of numbers of the returned midpoints
%% ========================================================================================

function [ xmp, cmpnum ] = midpoints( x )
 
global  rec

	if nargin < 1
		x = [];
	end

	if isempty(x)
		n = size(rec,1)*2-1;

		xmp = zeros(n,1);

		xmp(1:2:n,1) = rec(:,5);
		xmp(2:2:n,1) = mean([ rec(1:(end-1),5), rec(2:end,5)], 2);

		if nargout > 1
			cmpnum = transpose(1:n);
		end
	else
		n = length(x);

		xmp = zeros(n,1);
		cmpnum = xmp;
		
		m = midpoints();

		for i=1:n
			[ ~, k ] = min( abs(m - x(i)) );
		
			cmpnum(i,1) = k;
			xmp(i,1) = m(k,1);
		end
	end
end

