% Plots the line in map and section views

function plot_model()

global src rec model recline

	linestyle = [ 'r-'; 'b-'; 'm-' ];

	xrange = [min(recline.x), max(recline.x)];

	% datum depth

	datum_z = interp1(recline.x,recline.xyz(:,3),recline.midpoint_x,'linear','extrap');

	% plot map 

	figure(1)
	clf
	hold on

	plot(src(:,9),src(:,8),'ro')	% sources projected on the line
	plot(rec(:,9),rec(:,8),'bo')	% receivers projected on the line

	plot(recline.xyz(:,2),recline.xyz(:,1),'k-')

	plot(rec(:,3),rec(:,2),'b+');	text(rec(:,3),rec(:,2),num2str(rec(:,1)))
	plot(src(:,3),src(:,2),'r*')

	axis('equal')
	xlabel('Easting (m)')
	ylabel('Northing (m)')
	title('Map')

	% plot topography and cross-section

	figure(2)
	clf
	subplot(3,1,1)

	hold on

	if ~isempty(model.p0)
		plot(recline.midpoint_x,model.p0.^(-1),'-g')

		legend('Direct')
	end

	for i=1:size(model.p,2)
		plot(recline.midpoint_x,model.p(:,i).^(-1),linestyle(i,:))

%		legend(sprintf('Refr %d',i))
	end

	xlim(xrange)
	xlabel('Distance (m)')
	ylabel('V (m/ms)')
	title('Velocities')

	subplot(3,1,2)

	hold on

	if ~isempty(model.delta0)
		plot(recline.midpoint_x,model.delta0,'-g')

		legend('Delta0')
	end

	for i=1:size(model.tint,2)
		plot(recline.midpoint_x,model.tint(:,i),linestyle(i,:))

%		legend(sprintf('Refr %d',i))
	end

	xlim(xrange)
	xlabel('Distance (m)')
	ylabel('Delay (ms)')
	title('Delay times')

	subplot(3,1,3)

	hold on

	plot(recline.midpoint_x,datum_z,'k-')		% datum

	for i=1:size(model.z,2)
		plot(recline.midpoint_x,datum_z - model.z(:,i),linestyle(i,:))
	end

	%plot(rec(:,5),xy_rec(:,3),'bo')
	%plot(src(:,5),xy_src(:,3),'ro')

	plot(rec(:,5),rec(:,4),'b+')
	plot(src(:,5),src(:,4),'r*')

	xlim(xrange)
	xlabel('Distance (m)')
	ylabel('Elevation (m)')
	title('Cross-section')
end

