%% Plots in Figure 7 reciprocal time misfits
%% One or two tables of mismatches can be plotted
%%
%% Parameters:
%%      rtt1 - matrix of reciprocal tt misfits output by ttimes_reciprocal()
%%      rtt2 - optional another matrix to plot in a subplot
%
function plot_rtt( rtt1, rtt2 )

global src rec

	if nargin >= 2
		nplots = 2;
	else
		nplots = 1;
	end

	figure(7)
	clf

	subplot(1,nplots,1)

	hold on

	msize = abs(rtt1(:,3));

	msize = msize/max(msize)*20;	% scale to readable sizes

	for i = 1:size(rtt1,1)

		if rtt1(i,3) >= 0
			plot(rtt1(i,1),rtt1(i,2),'xb','MarkerSize',msize(i,1))
		else
			plot(rtt1(i,1),rtt1(i,2),'xr','MarkerSize',msize(i,1))
		end
	end

	xlabel('Forward shot number')
	ylabel('Reversed shot number')
	title(sprintf('Reciprocal time misties; RMS = %1.1f ms, MAX = %1.1f ms\n(Red < 0, Blue > 0)',...
				sqrt(mean(rtt1(:,3).^2)),max(abs(rtt1(:,3)))))
	
	if nplots > 1 

		subplot(1,nplots,2)

		hold on

		msize = abs(rtt2(:,3));

		msize = msize/max(msize)*20;	% scale to readable sizes

		for i = 1:size(rtt2,1)

			if rtt1(i,3) >= 0
				plot(rtt2(i,1),rtt2(i,2),'xb','MarkerSize',msize(i,1))
			else
				plot(rtt2(i,1),rtt2(i,2),'xr','MarkerSize',msize(i,1))
			end
		end

		xlabel('Forward shot number')
		ylabel('Reversed shot number')
		title(sprintf('Reciprocal time misties; RMS = %1.1f ms, MAX = %1.1f ms\n(Red < 0, Blue > 0)',...
				sqrt(mean(rtt2(:,3).^2)),max(abs(rtt2(:,3)))))
	end
end

