% Plots all travel times

function plot_ttimes()

global src rec ttdata ttpred recline

	linestyle_mute = 'g-x';
	linestyle = [ 'r-x'; 'b-x'; 'm-x' ];

	figure(4)
	clf

	% plot common-shot times

	subplot(3,1,1)
	hold on

	for i = 1:size(src,1)

		% plot tt vs. receiver position

		xt = ttimes_src(i);	

		ind = find(xt(:,1)<0 & xt(:,3) < 0 );		% wave backward

		plot(xt(ind,3)+ src(i,5),xt(ind,4),linestyle_mute)

		ind = find(xt(:,1)<0 & xt(:,3) >= 0 );	% wave forward

		plot(xt(ind,3)+ src(i,5),xt(ind,4),linestyle_mute)

		for j=1:size(linestyle,1)

			j1 = j-1;

			ind = find(xt(:,1)==j1 & xt(:,3) < 0 );		% wave backward

			plot(xt(ind,3)+ src(i,5),xt(ind,4),linestyle(j,:))

			ind = find(xt(:,1)==j1 & xt(:,3) >= 0 );	% wave forward

			plot(xt(ind,3)+ src(i,5),xt(ind,4),linestyle(j,:))
		end

		% mark shot number

		text(src(i,5),0,sprintf('%d(%d)', i, src(i,1)),'HorizontalAlignment','center')
	end

	xlabel('Distance (m)')
	ylabel('Travel time (ms)')
	title('First break times by shots')

	% plot times vs. midpoints

	subplot(3,1,2)
	hold on

	for i = 1:size(src,1)

		% plot tt vs. midpoint position

		xt = ttimes_src(i);	

		ind = find(xt(:,1)<0 & xt(:,3) < 0 );		% wave backward

		plot(xt(ind,3)*0.5+ src(i,5),xt(ind,4),linestyle_mute)

		ind = find(xt(:,1)<0 & xt(:,3) >= 0 );		% wave forward

		plot(xt(ind,3)*0.5+ src(i,5),xt(ind,4),linestyle_mute)

		for j=1:size(linestyle,1)

			j1 = j-1;

			ind = find(xt(:,1)==j1 & xt(:,3) < 0 );		% wave backward

			plot(xt(ind,3)*0.5+ src(i,5),xt(ind,4),linestyle(j,:))

			ind = find(xt(:,1)==j1 & xt(:,3) >= 0 );	% wave forward

			plot(xt(ind,3)*0.5+ src(i,5),xt(ind,4),linestyle(j,:))
		end

	end

	xlabel('Distance (m)')
	ylabel('Travel time (ms)')
	title('First break times by midpoints')

	% plot common-offset times

	subplot(3,1,3)
	hold on

	offset = (recline.min_offset+0.5):4:(recline.max_offset+0.5);	% offset grid

	for i = 1:length(offset)

		% plot common-offset curves vs. midpoint position
		% separate the direct waves and head waves by color

		xt = ttimes_offset(offset(i));	

		if isempty(xt)
			continue
		end

		ind = find(xt(:,1)==0);		% direct wave	

		if ~isempty(ind)
			plot(xt(ind,3),xt(ind,4),'r-')
		end

		ind = find(xt(:,1)==1);		% first head wave	

		if ~isempty(ind)
			plot(xt(ind,3),xt(ind,4),'b-')
		end

	end

	ylim([ -0 200 ])
	xlabel('Distance (m)')
	ylabel('Travel time (ms)')
	title('Common-offset first break times')
end

