% Plots travel times at control points

%% Parameters:
%%      srcno - Matrix with rows containing ranges of CMP coordinates, e.g.: [ 1, 10; 11 20 ]
%%	Vr - reduction velocity for plotting

function plot_ttimes_cp( cmpx, Vr )

global src rec recline model

	n = size(cmpx,1);
	x = recline.midpoint_x;

	linestyle = [ 'r-x'; 'b-x'; 'm-x' ];

	figure(6)
	clf

	for i = 1:n

	  % plot common-shot times

	  subplot(n,1,i)
	  hold on

	  ik = find( x >= cmpx(i,1) & x <= cmpx(i,2));

	  for j = 1:length(ik)

		% plot common-midpoint times 

		xt = ttimes_cmp(x(ik(j),1));

		if isempty(xt)
			continue
		end

		ind = find(xt(:,1)<0 & xt(:,3) < 0 );		% mute backward

		plot(abs(xt(ind,3)),xt(ind,4)-abs(xt(ind,3))/Vr,'g-x')

		ind = find(xt(:,1)<0 & xt(:,3) >= 0 );		% mute forward

		plot(abs(xt(ind,3)),xt(ind,4)-abs(xt(ind,3))/Vr,'g-x')

		for j=1:size(linestyle,1)

			j1 = j-1;

			ind = find(xt(:,1)==j1 & xt(:,3) < 0 );		% wave backward

			plot(abs(xt(ind,3)),xt(ind,4)-abs(xt(ind,3))/Vr,linestyle(j,:))

			ind = find(xt(:,1)==j1 & xt(:,3) >= 0 );	% wave forward

			plot(abs(xt(ind,3)),xt(ind,4)-abs(xt(ind,3))/Vr,linestyle(j,:))
		end

	  end

	%ylim([20 60])		% this seems to be the range of times of interest

	xlabel('Offset (m)')
	ylabel(sprintf('Travel time - Distance/%1.2f (ms)',Vr))
	title(sprintf('CMP times at X = %1.1f m to %1.1f m',cmpx(i,1),cmpx(i,2)))

      end % for i
end

