% Plots in figure 5 travel times from several groups of sources

%% Parameters:
%%      srcno - Matrix with rows containing ranges of source numbers, e.g.: [ 1, 10; 11 20 ]
%%	Vr - reduction velocity for plotting
%%		

function plot_ttimes_src( srcno, Vr )

global src rec

	n = size(srcno,1);
	nmax = size(src,1);

	linestyle = [ 'r-'; 'b-'; 'm-' ];
	figure(5)
	clf

	for i = 1:n

	  % plot common-shot times

	  subplot(n,1,i)
	  hold on

	  smin = max([1,srcno(i,1)]);
	  smax = min([nmax,srcno(i,2)]);

	  for i = smin:smax

		% plot direct waves vs. offset

		xt = ttimes_src(i);

		ind = find(xt(:,1)<0 & xt(:,3) < 0 );		% mute backward

		plot(xt(ind,3),xt(ind,4)-abs(xt(ind,3))/Vr,'g-')

		ind = find(xt(:,1)<0 & xt(:,3) >= 0 );		% mute forward

		plot(xt(ind,3),xt(ind,4)-abs(xt(ind,3))/Vr,'g-')

		for j=1:size(linestyle,1)

			j1 = j-1;

			ind = find(xt(:,1)==j1 & xt(:,3) < 0 );		% wave backward

			plot(xt(ind,3),xt(ind,4)-abs(xt(ind,3))/Vr,linestyle(j,:))

			ind = find(xt(:,1)==j1 & xt(:,3) >= 0 );	% wave forward

			plot(xt(ind,3),xt(ind,4)-abs(xt(ind,3))/Vr,linestyle(j,:))
		end

		plot(xt(ind,3),xt(ind,4)-abs(xt(ind,3))/Vr,'b-')

		% mark shot number

		text(xt(end,3),xt(end,4)-abs(xt(end,3))/Vr,sprintf('%d(%d)', i, src(i,1)))

	  end

	  xlabel('Offset (m)')
	  ylabel(sprintf('Travel time - Distance/%1.2f (ms)',Vr))
	  title(sprintf('First break times from shots %d to %d, X = %1.1f to %1.1f m',...
					smin,smax,src(smin,5),src(smax,5)))
	end
end

