%% Calculates depth of one refractor
%% ==============================================================================
%%
%% Parameters:
%%	delay - matrix formatted as model.p containing delay times for refractors
 
%%      irefr - refractor number ( >= 1)
%%  Returns:
%%	z - depth of the refractor at each coordinate in 'recline.midpoint'

function z = refr_depth(delay,irefr)

global recline model

	theta = real(asin(model.p(:,irefr)./model.p0));  	%  angle in uppermost layer

	z = 0.5*model.tint(:,1)./model.p0./cos(theta);	

	for i=(1+1):irefr		% go to layer below
			
		i1 = i-1;

		theta = real(asin(model.p(:,irefr)./model.p(:,i1))); 	% angle above boundary i

		ind = find( theta < 0.75 );	% angles are not too oblique

		if ~isempty(ind)
			z(ind,1) = z(ind,1) + 0.5*model.tint(ind,i)./model.p(ind,i1)./cos(theta(ind,1));
		end
	end
end	

