%% Sets branch number in 'xt' matrix based on offsets relative to point x
%% This is a helper function
%% ------------------------------------------------------------------------------------
%% Parameters:
%%      xt - input xt matrix
%%	x - coordinate for which the crossover offsets are measured
%%  Returns:
%%	xtout - copy of x with correct branches set
%% ========================================================================================

function xtout = set_branch( xt, x )
	
global	model
	
	xtout = xt;
	
	defbranch = size(model.crossover,2);	% default branch number (largest possible)

	% set branch numbers below defbranch

	if ~isempty(xt)
		xtout(:,1) = defbranch;

		aoffs = abs(xt(:,3));

	  	[ cdist, mute ] = crossover( 1:defbranch, x );	% all crossovers for position x

	  	for i=length(cdist):-1:1
			ind = find(aoffs < cdist(i));

			if ~isempty(ind)
				xtout(ind,1) = i-1;
			end
	  	end

		% check mute interval

		ind = find(aoffs < mute);

		if ~isempty(ind)
			xtout(ind,1) = -1;		% mute
		end
	end
end

