%% Applies corrections to all shot times in order to reduce the reciprocal-time
%% mismatches.
%% Shot times are found by solving a linear inverse problem 
%% for all pairs of shots with reciprocal time picks available:
%%
%%	time_of_shot_1 - time_of_shot_2 = reciprocal_tt_difference_between shot_1_and_2
%%
%% The mean of all shot times is set equal zero (it is unconstrained by the above equations)
%%
%% The resulting shot times are included in column 'model.shot_time' and subtracted 
%% from all travel times 
%% =========================================================================================
%%
%% Parameters:
%%      rtt - matrix returned by ttimes_reciprocal()
%%      apply - if any argument is given in this field, the corrections are applied to the model
%%		and travel times
%%  Returns:
%%	st - column of shot time corrections

function st = shot_times( rtt, apply )

global src ttdata model

	nt = size(rtt,1);
	ns = size(src,1);

  	L = zeros(nt+1,ns);

	for i=1:nt
  		L(i,rtt(i,1)) = 1;
		L(i,rtt(i,2)) = -1;
	end

	L(end,:) = 1.0;		% equation for Sum(shot_corrections) = 0

	if inOctave()
  		st = ols([ rtt(:,3); 0.0 ], L);		% Least-squares inverse

	else		% in Matlab
  		st = regress([ rtt(:,3); 0.0 ], L);	% Least-squares inverse
	end

	% save results in model

	model.shot_times = st;

	if nargin >= 2		% apply

		ttdata(:,4) = ttdata(:,4) - st(ttdata(:,1),1);	% subtract the shot time correction from picks
	end
end	

