%% Returns the travel-time field (grid of travel times in midpoint-offset space). 
%% 
%% The TTF is output at midpoints listed in 'recline.midpoint_x' and 'offsets' returned 
%% by this function
%%
%% The TTF is returned as a matrix, with rows corresponding to midpoints and columns
%% corresponding to offsets
%% =========================================================================================
%%
%% Parameters:
%%      offset_increment - desired offset increment
%%	max_offset - maximum offset in the grid
%%  Returns:
%%	ttf_t - direct-wave slowness (measured before the first crossover), sampled at every midpoint
%%	ttf_b - branch numbers (0, 1, 2, ...) corresponding to the points in the TTF grid
%%	offsets - row of offsets coordinates corresponding to columns of the TTF

function [ ttf_t, ttf_b, offsets ] = ttf( offset_increment, max_offset )

global src recline model

	offsets = (recline.min_offset+offset_increment):offset_increment:max_offset; 
				
	nx = length(recline.midpoint);
	noffs = length(offsets);

	ttf_t = zeros(nx,noffs);
	ttf_b = -ones(nx,noffs);	% default branch = -1

	for i=1:length(offsets)
		xt_offs = ttimes_offset(offsets(i));	% common offset curves and midpoint X
		
		if isempty(xt_offs)
		else
			ttf_t(:,i) = xt_offs(:,4);
			ttf_b(:,i) = xt_offs(:,1);
		end
	end
end	

