%% Extracts travel-time points for one or several midpoints 
%%
%% Output columns are the same as in ttimes_src()
%%
%% ---------------------------------------------------------------------
%% Parameters:
%%      cmpx - midpoint location (can be a column)
%%	offset_range - if not empty, this array of two values gives the range of offsets
%%		(third column in 'xt') to output. 
%%		The values in the row can be given in arbitrary order.
%%		If multiple rows are given, multiple travel-time branches 
%%		are concatenated 'xt'
%%  Returns:
%%	xt - matrix with columns (branch_number, cmp number, offset, time)
%% ========================================================================================

function xt = ttimes_cmp( cmpx, offset_range )
 
global src rec recline ttdata

	if nargin < 2
		offset_range = [];
	else
	   	offset_range = sort(offset_range,2);
	end

	xt = [];

	for j=1:length(cmpx)

	  xt1 = [];

	  % go through all sources, extract points at given midpoint 

	  for i=1:size(src,1)

		xt2 = ttimes_src( i, [], cmpx(j)*2 - src(i,5) );

		if ~isempty(xt2)
			xt1 = [ xt1; zeros(size(xt2,1),1), xt2(:,2:4) ];	% branch number=0 for now
		end
	  end

	  if isempty(xt1)
		continue
	  end

	  % sort by offset

	  [~,ind ] = sort(xt1(:,3));

 	  xt1 = xt1(ind,:);

	  % set branch numbers

	  xt1 = set_branch( xt1, cmpx(j) );

	  % set cmp numbers

	  [~, ind ] = min( abs(recline.midpoint_x-cmpx(j)) );

	  xt1(:,2) = recline.midpoint(ind);

	  % select offset ranges

	  if isempty(offset_range)
	    xt = xt1;

	  else

	    for i=1:size(offset_range,1)

		ind = find(xt1(:,3) >= offset_range(i,1) & xt1(:,3) < offset_range(i,2) );

		if ~isempty(ind)
			xt = [ xt; xt1(ind,:) ];
		end
	    end
	  end

	end
end

