%% Adjusts intercept times in all layers so that they become consistent with crossover distances
%% (i.e., the travel-time branches intersect at crossover distances)
%% =========================================================================================
%%
%% Parameters:
%%      p0 - column of ray parameters of direct wave at each coordinate in 'xmp'
%%      p - matrix of ray parameters of head waves at each coordinate xmp
%%	xmp - column of coordinates at which the calculations are performed
%%  Returns:
%%	intercept - matrix of intercept values for each headwave in 'p'

function intercept = ttimes_intercept(p0,p,xmp)

	intercept = zeros(size(p));	% init

	if size(p,2) > 0
		xc = crossover(1,xmp);		% first crossover distances
		
		intercept(:,1) = (p0 - p(:,1)).*xc;

		for i=2:size(p,2)
			xc = crossover(i,xmp);		% crossover distances
		
			intercept(:,i) = intercept(:,i-1) + (p(:,i-1) - p(:,i)).*xc;
		end
	end
end	

