%% Extracts travel-time points from all travel-time branches at given offsets
%%
%% Output values are similar to ttimes_src(), but the second column is the
%% midpoint number, and the third one is the midpoint X
%% ---------------------------------------------------------------------
%% Parameters:
%%      offset - offset value for output (can be an array, then all output 
%%		tt branches are concatenated )
%%  Returns:
%%	xt - matrix with columns (branch_number, midpoint_number, midpoint_x, time)
%% =============================================================================================

function xt = ttimes_offset( offset )
 
global src rec ttdata recline model

	xt = [];
	xmp = recline.midpoint_x;		% coordinates of midpoint grid
	cmp = recline.midpoint;			

	dx = (xmp(end,1) - xmp(1,1) )/(size(xmp,1)-1);	% rough size of cmp bin

	for j=1:length(offset)

	  % go through all sources, extract points at given offsets 

	  xt1 = [];

	  for i=1:size(src,1)

		xt2 = ttimes_src( i, [], offset(j) + src(i,5) );

		if ~isempty(xt2)
			xt1 = [ xt1; xt2(:,1), src(i,5) + xt2(:,3)*0.5, xt2(:,4) ];	
						% branch number, midpoint x, tt value
		end
	  end

	  if size(xt1,1) >= 2	% can interpolate

	  	% sort by increasing midpoints

	  	[ ~, ind ] = sort(xt1(:,2));
	  	xt1 = xt1(ind,:);

		% pad values on both ends of the range with constants

		if xt1(:,2) > xmp(1,1)
			xt1 = [ xt1(1,:); xt1 ]; 
			xt1(1,2) = xmp(1,1);
		end

		if xt1(end,2) < xmp(end,1)
			xt1 = [ xt1; xt1(end,:) ]; 
			xt1(end,2) = xmp(end,1);
		end

		% if any points from reversed branches are too close together, replace 
		% their times with average

		ind = find(xt1(2:end,2) - xt1(1:(end-1),2) < dx);	% indices of close points

		for i =1:length(ind)
			j1 = ind(i);
			j2 = j1+1;

			t = (xt1(j1,3) + xt1(j2,3) )*0.5;

			xt1(j1,3) = t;
			xt1(j2,3) = t;
		end

	  	% interpolate times at all midpoints
	  	% set branch numbers based on the given offset

	  	xt = [ xt; branch(xmp,offset(j)), cmp, xmp, interp1(xt1(:,2),xt1(:,3),xmp,'linear','extrap') ];

	  end

	end	% for

%xt

end

