%% Returns all pairs of reciprocal sources with travel-time differences
%%
%% Parameters:
%%      none
%%
%%  Returns:
%%	rtt - matrix with each row containing:
%%		1) source number (row in 'src') of the first reciprocal source in a pair (forward)
%%		2) source number (row in 'src') of the second reciprocal source in a pair (reversed)
%%		1) difference between the forward and reversed reciprocal travel times


function rtt = ttimes_reciprocal()

global src

	ns = size(src,1);

	rtt = [];

	for j=2:ns		% reversed shots
		for i=1:(j-1)	% forward shots

			xt1 = ttimes_src( i, [], src(j,5) );	% forward time

			if ~isempty(xt1)
				xt2 = ttimes_src( j, [], src(i,5) );	% reversed time

				if ~isempty(xt2)
					rtt = [ rtt; i, j, xt1(1,4) - xt2(1,4)];
				end
			end
		end
	end
end	

